Revision: 19736
          http://sourceforge.net/p/edk2/code/19736
Author:   lgao4
Date:     2016-01-25 04:45:55 +0000 (Mon, 25 Jan 2016)
Log Message:
-----------
Nt32Pkg: Fix asserts from running Nt32 64-bit on Win8

On Windows 8, 64-bit NT32 images are loaded above 4GB.

Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Cinnamon Shia <[email protected]>
Reviewed-by: Liming Gao <[email protected]>

Modified Paths:
--------------
    trunk/edk2/Nt32Pkg/Nt32Pkg.dsc
    trunk/edk2/Nt32Pkg/Sec/SecMain.c
    trunk/edk2/Nt32Pkg/WinNtAutoScanPei/WinNtAutoScan.c
    trunk/edk2/Nt32Pkg/WinNtFlashMapPei/FlashMap.c
    trunk/edk2/Nt32Pkg/WinNtFlashMapPei/WinNtFlashMapPei.inf

Modified: trunk/edk2/Nt32Pkg/Nt32Pkg.dsc
===================================================================
--- trunk/edk2/Nt32Pkg/Nt32Pkg.dsc      2016-01-25 03:38:19 UTC (rev 19735)
+++ trunk/edk2/Nt32Pkg/Nt32Pkg.dsc      2016-01-25 04:45:55 UTC (rev 19736)
@@ -6,6 +6,7 @@
 #
 # Copyright (c) 2015, Hewlett-Packard Development Company, L.P.<BR>
 # Copyright (c) 2006 - 2015, Intel Corporation. All rights reserved.<BR>
+# (C) Copyright 2016 Hewlett Packard Enterprise Development LP<BR>
 #
 #    This program and the accompanying materials
 #    are licensed and made available under the terms and conditions of the BSD 
License
@@ -276,6 +277,9 @@
   gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageFtwSpareBase|0
   gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageFtwWorkingBase|0
   gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageVariableBase|0
+  gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageFtwSpareBase64|0
+  gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageFtwWorkingBase64|0
+  gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageVariableBase64|0
 
 [PcdsDynamicDefault.Ia32]
   
gEfiNt32PkgTokenSpaceGuid.PcdWinNtFileSystem|L".!..\..\..\..\EdkShellBinPkg\Bin\Ia32\Apps"|VOID*|106

Modified: trunk/edk2/Nt32Pkg/Sec/SecMain.c
===================================================================
--- trunk/edk2/Nt32Pkg/Sec/SecMain.c    2016-01-25 03:38:19 UTC (rev 19735)
+++ trunk/edk2/Nt32Pkg/Sec/SecMain.c    2016-01-25 04:45:55 UTC (rev 19736)
@@ -1,6 +1,7 @@
 /**@file
 
 Copyright (c) 2006 - 2015, Intel Corporation. All rights reserved.<BR>
+(C) Copyright 2016 Hewlett Packard Enterprise Development LP<BR>
 This program and the accompanying materials
 are licensed and made available under the terms and conditions of the BSD 
License
 which accompanies this distribution.  The full text of the license may be 
found at
@@ -809,7 +810,7 @@
   // Align buffer on section boundry
   //
   ImageContext.ImageAddress += ImageContext.SectionAlignment - 1;
-  ImageContext.ImageAddress &= ~(ImageContext.SectionAlignment - 1);
+  ImageContext.ImageAddress &= 
~((EFI_PHYSICAL_ADDRESS)ImageContext.SectionAlignment - 1);
 
   Status = PeCoffLoaderLoadImage (&ImageContext);
   if (EFI_ERROR (Status)) {

Modified: trunk/edk2/Nt32Pkg/WinNtAutoScanPei/WinNtAutoScan.c
===================================================================
--- trunk/edk2/Nt32Pkg/WinNtAutoScanPei/WinNtAutoScan.c 2016-01-25 03:38:19 UTC 
(rev 19735)
+++ trunk/edk2/Nt32Pkg/WinNtAutoScanPei/WinNtAutoScan.c 2016-01-25 04:45:55 UTC 
(rev 19736)
@@ -1,6 +1,7 @@
 /**@file
 
 Copyright (c) 2006, Intel Corporation. All rights reserved.<BR>
+(C) Copyright 2016 Hewlett Packard Enterprise Development LP<BR>
 This program and the accompanying materials                          
 are licensed and made available under the terms and conditions of the BSD 
License         
 which accompanies this distribution.  The full text of the license may be 
found at        
@@ -176,9 +177,9 @@
   } while (!EFI_ERROR (Status));
 
   //
   // Build the CPU hob with 36-bit addressing and 16-bits of IO space.
   //
-  BuildCpuHob (36, 16);
+  BuildCpuHob (52, 16);
 
   //
   // Build GUIDed Hob that contains the Memory Type Information array

Modified: trunk/edk2/Nt32Pkg/WinNtFlashMapPei/FlashMap.c
===================================================================
--- trunk/edk2/Nt32Pkg/WinNtFlashMapPei/FlashMap.c      2016-01-25 03:38:19 UTC 
(rev 19735)
+++ trunk/edk2/Nt32Pkg/WinNtFlashMapPei/FlashMap.c      2016-01-25 04:45:55 UTC 
(rev 19736)
@@ -1,6 +1,7 @@
 /**@file
 
 Copyright (c) 2006, Intel Corporation. All rights reserved.<BR>
+(C) Copyright 2016 Hewlett Packard Enterprise Development LP<BR>
 This program and the accompanying materials                          
 are licensed and made available under the terms and conditions of the BSD 
License         
 which accompanies this distribution.  The full text of the license may be 
found at        
@@ -85,9 +86,15 @@
   //
   // Relocate the base of FV region 
   // 
-  PcdSet32 (PcdFlashNvStorageVariableBase, PcdGet32 
(PcdWinNtFlashNvStorageVariableBase) + (UINT32) FdBase);
-  PcdSet32 (PcdFlashNvStorageFtwWorkingBase, PcdGet32 
(PcdWinNtFlashNvStorageFtwWorkingBase) + (UINT32) FdBase);
-  PcdSet32 (PcdFlashNvStorageFtwSpareBase, PcdGet32 
(PcdWinNtFlashNvStorageFtwSpareBase) + (UINT32) FdBase);
+  if (FdBase >= BASE_4GB) {
+    PcdSet64 (PcdFlashNvStorageVariableBase64, PcdGet32 
(PcdWinNtFlashNvStorageVariableBase) + (UINT64) FdBase);
+    PcdSet64 (PcdFlashNvStorageFtwWorkingBase64, PcdGet32 
(PcdWinNtFlashNvStorageFtwWorkingBase) + (UINT64) FdBase);
+    PcdSet64 (PcdFlashNvStorageFtwSpareBase64, PcdGet32 
(PcdWinNtFlashNvStorageFtwSpareBase) + (UINT64) FdBase);
+  } else {
+    PcdSet32 (PcdFlashNvStorageVariableBase, PcdGet32 
(PcdWinNtFlashNvStorageVariableBase) + (UINT32) FdBase);
+    PcdSet32 (PcdFlashNvStorageFtwWorkingBase, PcdGet32 
(PcdWinNtFlashNvStorageFtwWorkingBase) + (UINT32) FdBase);
+    PcdSet32 (PcdFlashNvStorageFtwSpareBase, PcdGet32 
(PcdWinNtFlashNvStorageFtwSpareBase) + (UINT32) FdBase);
+  }
 
   return EFI_SUCCESS;
 }

Modified: trunk/edk2/Nt32Pkg/WinNtFlashMapPei/WinNtFlashMapPei.inf
===================================================================
--- trunk/edk2/Nt32Pkg/WinNtFlashMapPei/WinNtFlashMapPei.inf    2016-01-25 
03:38:19 UTC (rev 19735)
+++ trunk/edk2/Nt32Pkg/WinNtFlashMapPei/WinNtFlashMapPei.inf    2016-01-25 
04:45:55 UTC (rev 19736)
@@ -3,6 +3,7 @@
 #
 # This module installs FlashMap PPI which is used to get flash layout 
information.
 # Copyright (c) 2006 - 2010, Intel Corporation. All rights reserved.<BR>
+# (C) Copyright 2016 Hewlett Packard Enterprise Development LP<BR>
 #
 #  This program and the accompanying materials
 #  are licensed and made available under the terms and conditions of the BSD 
License
@@ -49,10 +50,13 @@
 [Pcd]
   gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageFtwWorkingSize
   gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageFtwWorkingBase
+  gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageFtwWorkingBase64
   gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageFtwSpareSize
   gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageFtwSpareBase
+  gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageFtwSpareBase64
   gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageVariableSize
   gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageVariableBase
+  gEfiMdeModulePkgTokenSpaceGuid.PcdFlashNvStorageVariableBase64
 
   gEfiNt32PkgTokenSpaceGuid.PcdWinNtFlashNvStorageFtwWorkingBase
   gEfiNt32PkgTokenSpaceGuid.PcdWinNtFlashNvStorageFtwSpareBase


------------------------------------------------------------------------------
@@ -176,9 +177,9 @@
 
   //
-  // Build the CPU hob with 36-bit addressing and 16-bits of IO space.
+  // Build the CPU hob with 52-bit addressing and 16-bits of IO space.
   //
Site24x7 APM Insight: Get Deep Visibility into Application Performance
APM + Mobile APM + RUM: Monitor 3 App instances at just $35/Month
Monitor end-to-end web transactions and take corrective actions now
Troubleshoot faster and improve end-user experience. Signup Now!
http://pubads.g.doubleclick.net/gampad/clk?id=267308311&iu=/4140
_______________________________________________
edk2-commits mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/edk2-commits

Reply via email to